@@ -1,7 +1,7 @@
-"""Manages installed Bundle packages."""
+"""Create and manage bundle packages."""
 from __future__ import absolute_import
 
-VERSION = (0, 0, 1)
+VERSION = (1, 0, 0)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
@@ -9,3 +9,5 @@ __homepage__ = "http://github.com/ask/bundle/"
 __docformat__ = "restructuredtext en"
 
 # -eof meta-
+
+from .bundle import Bundle
